@@ -11,6 +11,8 @@
 #include <stdlib.h>
 #include <string.h>
 
+#include <math.h>
+
 #ifdef __HAIKU__
 #include <FindDirectory.h>
 #include <fs_info.h>
@@ -20,16 +22,20 @@
 
 #include <alsa/seq_midi_event.h>
 
-#include "lv2/lv2plug.in/ns/ext/dyn-manifest/dyn-manifest.h"
-#include "lv2/lv2plug.in/ns/ext/event/event.h"
-#include "lv2/lv2plug.in/ns/ext/uri-map/uri-map.h"
-
 #include <NASPRO/brit/lib.h>
 
 #define API	NACORE_PUBLIC NACORE_EXPORT
 
 #include "config.h"
 
+#ifdef HAVE_DYNMANIFEST_H
+# include <lv2/lv2plug.in/ns/ext/dynmanifest/dynmanifest.h>
+#else
+# include <lv2/lv2plug.in/ns/ext/dyn-manifest/dyn-manifest.h>
+#endif
+#include <lv2/lv2plug.in/ns/ext/event/event.h>
+#include <lv2/lv2plug.in/ns/ext/uri-map/uri-map.h>
+
 #include "bridge.h"
 #include "pluglib.h"
 #include "plugin.h"
