@@ -12,5 +12,4 @@ NACORE_PRIVATE void
 plugin_load(nabrit_pluglib pluglib, const DSSI_Descriptor *desc);
 
 NACORE_PRIVATE void
-plugin_unload(void *value, nacore_msg_context msg_context, void *msg_opaque,
-	      void *opaque);
+plugin_unload(void *value, void *opaque);
