@@ -11,8 +11,7 @@
 #include "internal.h"
 
 NACORE_PRIVATE void
-pluglib_load(void *value, nacore_msg_context msg_context, void *msg_opaque,
-	     void *opaque)
+pluglib_load(void *value, void *opaque)
 {
 	const char *filename;
 	nacore_dl_handle handle;
@@ -51,16 +50,14 @@ pluglib_load(void *value, nacore_msg_context msg_context, void *msg_opaque,
 }
 
 NACORE_PRIVATE void
-pluglib_unload(void *value, nacore_msg_context msg_context, void *msg_opaque,
-	       void *opaque)
+pluglib_unload(void *value, void *opaque)
 {
 	nabrit_pluglib pluglib;
 	const char *filename;
 
 	pluglib = (nabrit_pluglib)value;
 
-	nabrit_pluglib_free_plugins(bridge, pluglib, plugin_unload, NULL, NULL,
-				    NULL);
+	nabrit_pluglib_free_plugins(bridge, pluglib, plugin_unload, NULL);
 
 	filename = nabrit_pluglib_get_filename(pluglib);
 	free((void *)filename);
