@@ -9,9 +9,7 @@
  */
 
 NACORE_PRIVATE void
-pluglib_load(void *value, nacore_msg_context msg_context, void *msg_opaque,
-	     void *opaque);
+pluglib_load(void *value, void *opaque);
 
 NACORE_PRIVATE void
-pluglib_unload(void *value, nacore_msg_context msg_context, void *msg_opaque,
-	       void *opaque);
+pluglib_unload(void *value, void *opaque);
